import React, { FormEvent, useState } from 'react';

type props = {
  parentFunction: (arg0: string) => void;
  options: Array<string | number>; // Depends on if the user is choosing strings or numbers
  optionLabel: string;
}

const DropDownToggle = (props: props) => {
  const [value, setValue] = useState(''); // The currently submitted element

  const handleChange = (event: React.ChangeEvent<HTMLSelectElement>) => { // Called whenever user changes choice
    event.preventDefault(); // To prevent default HTML behavior
    setValue(event.currentTarget.value); // Update the value with the newly selected one
  };

  const handleSubmit = (event: FormEvent) => { // Called once the form is submitted using the button
    event.preventDefault(); // To prevent default HTML behavior
    props.parentFunction(value); // Calls the function of the parent with the submitted value
  };

  const renderOptions = () => { // To render a varying amount of options
    return props.options.map(opt => <option value={opt} key={opt}>{opt}</option>);
  };

  return (<div className={'drop-down-toggle'}>
    <form onSubmit={handleSubmit}>
      <label>
        {props.optionLabel}
        <select value={value} onChange={handleChange}>
          {renderOptions()}
        </select>
      </label>
      <input type={'submit'} value={'Submit'}/>
    </form>
  </div>);
};

export default DropDownToggle;